/*
 * BusinessObjectTest.java
 * JUnit based test
 *
 * Created on 18. leden 2007, 9:31
 */

package cz.novoj.emt.mock;

import cz.novoj.emt.BusinessObject;
import cz.novoj.emt.ILogger;
import cz.novoj.emt.IMessageSender;
import cz.novoj.emt.exception.SendException;
import static org.easymock.EasyMock.*;
import org.junit.Before;
import org.junit.Test;

/**
 * Test for business object.
 * 
 * @author Rodina Novotnych
 */
public class BusinessObjectMockTest {
    private BusinessObject tested;
	private ILogger loggerMock;
	private IMessageSender messageMock;

	@Before
	public void init() {
		tested = new BusinessObject();
		loggerMock = createMock(ILogger.class);
        messageMock = createMock(IMessageSender.class);
		tested.setLogger(loggerMock);
        tested.setMessageSender(messageMock);
	}
    
    /**
     * Tests performBusinessLogic with test Mocks.
     **/
    @Test 
    public void testPerformBusinessLogicWithMocksLowerBound() throws SendException {
        messageMock.send(
                    BusinessObject.RECEIVER_ONE, 
                    BusinessObject.SENDER, 
                    BusinessObject.SUBJECT, 
                    BusinessObject.BODY_LOWER_BOUND);
        replay(loggerMock, messageMock);
        tested.performBussinesLogic(1);
        verify(loggerMock, messageMock);
    }
    
    /**
     * Tests performBusinessLogic with test Mocks.
     **/
    @Test 
    public void testPerformBusinessLogicWithMocksHigherBound() throws SendException {
        messageMock.send(
                    BusinessObject.RECEIVER_TWO, 
                    BusinessObject.SENDER, 
                    BusinessObject.SUBJECT, 
                    BusinessObject.BODY_HIGHER_BOUND);
        
        replay(loggerMock, messageMock);
        tested.performBussinesLogic(11);
        verify(loggerMock, messageMock);
    }
    
    /**
     * Tests performBusinessLogic with test Mocks.
     **/
    @SuppressWarnings({"ThrowableResultOfMethodCallIgnored", "ThrowableInstanceNeverThrown"})
	@Test
    public void testPerformBusinessLogicWithMocksWithException() throws SendException {
        messageMock.send((String)notNull(), (String)notNull(), (String)notNull(), (String)notNull());
        expectLastCall().andThrow(new SendException());
		loggerMock.logError((String) notNull(), isA(SendException.class));
        replay(loggerMock, messageMock);
        tested.performBussinesLogic(1);
        verify(loggerMock, messageMock);
    }    
    
}
